@@ -13,7 +13,7 @@
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 
-Version = '1.5'
+Version = '1.6'
 
 import os
 import sys
@@ -26,7 +26,7 @@ from CSSUfeaturesUI import *
 
 #############################################################################################################
 
-PathApp             = '/opt/CSSUfeatures'             # application path
+PathApp             = '/opt/CSSUfeatures/'             # application path
 PathSystem          = '/usr/share/hildon-desktop/'    # main path
 ConfigSystem        = 'transitions.ini'               # name of system config file
 PathTheme           = '/etc/hildon/theme/'            # main path (if themes are in place)
@@ -34,7 +34,9 @@ ConfigTheme         = 'transitions.ini'               # name of system config fi
 PathTemp            = '/home/user/.CSSUfeatures/'     # temp path of files
 ConfigTempSystem    = 'CSSUfeatures_temp_system'      # name of temp config file from/for system
 ConfigTempTheme     = 'CSSUfeatures_temp_theme'       # name of temp config file from/for theme
-
+PathSystemUi        = '/etc/systemui/'                # path to the storage of xml files for the power key menu
+ConfigSystemUi      = 'CSSUfeatures.xml'              # name of the applications' xml file for the power key menu
+updateSettings      = 'updateTransitions'             # name of the script used to pass root commands
 #############################################################################################################
 
 def checkFile(Path, File):       
@@ -137,7 +139,7 @@ def doUpdateConfigSystem():
 
     time.sleep(1)
     try:
-       os.system('sudo %s/updateTransitions copyTempSystem' % PathApp)
+       os.system('sudo %s%s copyTempSystem' % (PathApp, updateSettings))
     except:
        return False
     else: 
@@ -148,7 +150,7 @@ def doUpdateConfigTheme():
 
     time.sleep(1)
     try:
-       os.system('sudo %s/updateTransitions copyTempTheme' % PathApp)
+       os.system('sudo %s%s copyTempTheme' % (PathApp, updateSettings))
     except:
        return False
     else: 
@@ -254,6 +256,15 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
              QtCore.QObject.connect(self.ui.actionRestoreDefaults, QtCore.SIGNAL('triggered()'), self.doRestoreDefaults)
              QtCore.QObject.connect(self.ui.actionRebootDevice, QtCore.SIGNAL('triggered()'), self.doRebootDevice)
+             QtCore.QObject.connect(self.ui.actionAddPowerKeyEntry, QtCore.SIGNAL('triggered()'), self.doAddPowerKeyEntry)
+             QtCore.QObject.connect(self.ui.actionRemovePowerKeyEntry, QtCore.SIGNAL('triggered()'), self.doRemovePowerKeyEntry)
+               ##Enable only the valid menu entry 
+             if checkFile(PathSystemUi, ConfigSystemUi) == True:
+                 self.ui.actionAddPowerKeyEntry.setEnabled(False)
+                 print 'powerKey entry TRUE'
+             else:
+                 self.ui.actionRemovePowerKeyEntry.setEnabled(False)
+                 print 'powerKey entry FALSE'
              
              ## Check which config file to use.
              checkConfigFile()
@@ -267,6 +278,26 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              stackwindow = CSSUfeaturesAbout(self)
              stackwindow.show()
 
+        def doAddPowerKeyEntry(self):
+             '''Add entry in the Power Key menu'''
+             
+             os.system('sudo %s%s addPowerKeyEntry' % (PathApp, updateSettings) )
+             self.ui.actionAddPowerKeyEntry.setEnabled(False)
+             self.ui.actionRemovePowerKeyEntry.setEnabled(True)
+             os.system('sudo %s%s updatePowerKeyEntry' % (PathApp, updateSettings) )
+             message = 'Added entry in the Power Key Menu'
+             showQuickMessage(message)
+
+        def doRemovePowerKeyEntry(self):
+             '''Remove entry from the Power Key menu'''
+
+             os.system('sudo %s%s deletePowerKeyEntry' % (PathApp, updateSettings) )
+             self.ui.actionAddPowerKeyEntry.setEnabled(True)
+             self.ui.actionRemovePowerKeyEntry.setEnabled(False)
+             os.system('sudo %s%s updatePowerKeyEntry' % (PathApp, updateSettings) )
+             message = 'Removed entry from the Power Key Menu'
+             showQuickMessage(message)
+                     
         def doRestoreDefaults(self):
              ''' Restore the default configuration file.'''
              
@@ -274,7 +305,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              showQuickMessage(message)
              
              try:
-                 os.system('sudo %s/updateTransitions copyDefault' % PathApp)
+                 os.system('sudo %s%s copyDefault' % (PathApp, updateSettings))
              except:
                  message = 'The default transitions.ini file could not be restored to the system.'
              else: 
@@ -286,7 +317,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              message = 'INFO: Device is going to be restarted.\nThe application is exiting..'
              showQuickMessage(message)
              
-             os.system('sudo %s/updateTransitions rebootDevice &' % PathApp)
+             os.system('sudo %s%s rebootDevice &' % (PathApp, updateSettings))
              sys.exit(1)
      
         def doSetCurrent(self):
